src/Graphics/GameView.hh
branchnew_graphics
changeset 414 cede5463b845
parent 412 721c60072091
child 416 38cba347a3a9
--- a/src/Graphics/GameView.hh	Wed Jan 21 23:25:29 2009 +0200
+++ b/src/Graphics/GameView.hh	Thu Jan 22 00:02:53 2009 +0200
@@ -4,15 +4,17 @@
 #include "Drawable.hh"
 #include "PlayerInfoView.hh"
 #include "MessageView.hh"
+#include "Input.hh"
 #include "../GameState.hh"
 
-#include "../Input.hh"
 
 namespace graphics
 {
 
 /**
  * This is the main in-game view, which is what the player sees when they are playing
  */    
 class GameView : public View {
 protected:
@@ -63,6 +65,11 @@
         return PixelArea(400, area.bottom - 100, area.right, area.bottom);
     }
 
+    /**
+     * Handle GUI input
+     */
+    void handleInput (GuiInput flags, TimeMS dt);
+
 public:    
     
     /**
@@ -4,15 +4,17 @@
 
 /**
- * This is the main in-game view, which is what the player sees when they are playing
+ * This is the main in-game view, which is what the player sees when they are playing.
+ *
+ * This enables graphics->input.gui/player
  */    
 class GameView : public View {